(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     79849,       1788]
NotebookOptionsPosition[     71615,       1671]
NotebookOutlinePosition[     72172,       1692]
CellTagsIndexPosition[     72129,       1689]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 9, Section 9.9, Figures 9.33\[Dash]34", "Section",ExpressionUUID->"6e8e70b0-1575-4ccc-baaf-e425552046ca"],

Cell[TextData[{
 "Here we make use of many of the functions defined in, for example, ",
 StyleBox["Fig.2.15.nb",
  FontWeight->"Bold"],
 ".  First we need to define functions ",
 StyleBox["Trunc", "Input"],
 ", ",
 StyleBox["Int", "Input"],
 " and ",
 StyleBox["Frac", "Input"],
 " that can truncate, take the integer and fractional parts of positive and \
negative real numbers."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e296fbb8-279f-4311-9ffc-84626ebae8f5"],

Cell["\<\
Trunc[x_] := If[x > 0, Floor[x], Ceiling[x]]
Int[x_] := Floor[x]
Frac[x_] := x - Trunc[x]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"f765c5d6-1ee9-481a-8213-d99cb21b968a"],

Cell[TextData[{
 "Now define the function ",
 StyleBox["JulianDate", "Input"],
 " to calculate the Julian Date for a given calendar year, month, day and UT. \
 This uses the algorithm given in Appendix A.3."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ac98eb6e-3dec-4709-8635-ac94d9793a73"],

Cell[CellGroupData[{

Cell["\<\
JulianDate[{year_Integer, month_Integer, 
            day_Integer, ut_}] :=
Module[{y, m, b},
  If[month <= 2,
     y = year-1; m = month+12,
     y = year;   m = month    ];
  If[year < 1582, b = -2];
  If[year > 1582, b = Int[y/400] - Int[y/100]];
  If[year == 1582,
     If[month < 10, b = -2];
     If[month > 10, b = Int[y/400] - Int[y/100]];
     If[month == 10,
        If[day <= 4,  b = -2];
        If[day >= 15, b = Int[y/400] - Int[y/100]];
        If[day > 4 && day < 15, Print[\"Missing day\"]]
       ]
    ];
  N[If[y > 0, Int[365.25*y], Trunc[365.25*y-0.75]] + 
    Int[30.6001*(m+1)] + b + 1720996.5 + day + ut/24,
    12]];     \
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"da5b1b5f-250f-4787-875d-216292d581e1"],

Cell[BoxData[
 TemplateBox[{
  "SetDelayed", "write", 
   "\"Tag \\!\\(\\*RowBox[{\\\"JulianDate\\\"}]\\) in \
\\!\\(\\*RowBox[{\\\"JulianDate\\\", \\\"[\\\", RowBox[{\\\"{\\\", RowBox[{\\\
\"year_Integer\\\", \\\",\\\", \\\"month_Integer\\\", \\\",\\\", \
\\\"day_Integer\\\", \\\",\\\", \\\"ut_\\\"}], \\\"}\\\"}], \\\"]\\\"}]\\) is \
Protected.\"", 2, 4, 1, 25294014174312623140, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.812012607571069*^9, 3.8120126620704*^9},
 CellLabel->
  "During evaluation of \
In[4]:=",ExpressionUUID->"67f9b87f-7817-410f-886c-d4ef558c0d37"]
}, Open  ]],

Cell["\<\
Calculate the Julian date corresponding to 1st September 1989 when Pluto was \
at perihelion.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3c7aeaef-b3f9-4c07-be4d-8f4bc4dbd77f"],

Cell[CellGroupData[{

Cell["date = JulianDate[{1989, 9, 1, 0.}]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"8b1fa439-e43b-4175-b21b-50e24bbee1de"],

Cell[BoxData["2.4477704583333335`*^6"], "Output",
 CellChangeTimes->{3.812012607706616*^9, 3.812012662236774*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"f0580252-9f10-4a66-a33f-9b3a6759a615"]
}, Open  ]],

Cell[TextData[{
 "Next we define a function ",
 StyleBox["PrintPlanetXYZ", "Input"],
 " that will use the data in Tables A.2 and A.3 to derive and print out \
details of the calculation of the coordinates and orbital elements of planet \
number ",
 StyleBox["id", "Input"],
 " at Julian Date ",
 StyleBox["jd", "Input"],
 ".  Note that ",
 StyleBox["id", "Input"],
 "=1,2,...,9 corresponds to Mercury, Venus, ..., Pluto."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1e6ea287-f3f6-406f-a963-81a6d3dcd9d1"],

Cell["\<\
PrintPlanetXYZ[id_,jd_] :=
Module[{ a = {    0.38709893,     0.72333199,     1.00000011, 
                  1.52366231,     5.20336301,     9.53707032,
                 19.19126393,    30.06896348,    39.48168677},
        \[Delta]a = {    0.00000066,     0.00000092,    -0.00000005,
                 -0.00007221,     0.00060737,    -0.00301530,
                  0.00152025,    -0.00125196,    -0.00076912},
         e = {    0.20563069,     0.00677323,     0.01671022,
                  0.09341233,     0.04839266,     0.05415060,
                  0.04716771,     0.00858587,     0.24880766},
        \[Delta]e = {    0.00002527,    -0.00004938,    -0.00003804,
                  0.00011902,    -0.00012880,    -0.00036762,
                 -0.00019150,     0.00002514,     0.00006465},
         i = {    7.00487,        3.39471,        0.00005,
                  1.85061,        1.30530,        2.48446,
                  0.76986,        1.76917,       17.14175   },
        \[Delta]i = {  -23.51,          -2.86,         -46.94,
                -25.47,          -4.15,           6.11,
                 -2.09,          -3.64,          11.07      },
         \[CapitalOmega] = {   48.33167,       76.68069,      -11.26064,
                 49.57854,      100.55615,      113.71504,
                 74.22988,      131.72169,      110.30347   },
        \[Delta]\[CapitalOmega] = { -446.30,        -996.89,      -18228.25,
              -1020.19,        1217.17,       -1591.05,
               1681.40,        -151.25,         -37.33      },
         \[CurlyPi] = {   77.45645,      131.53298,      102.94719,
                336.04084,       14.75385,       92.43194,
                170.96424,       44.97135,      224.06676   },
        \[Delta]\[CurlyPi] = {  573.57,        -108.80,        1198.28,
               1560.78,         839.93,       -1948.89,
               1312.56,        -844.43,        -132.25      },
         \[Lambda] = {  252.25084,      181.97973,      100.46435,
                355.45332,       34.40438,       49.94432,
                313.23218,      304.88003,      238.92881   },
        \[Delta]\[Lambda] = {261628.29,      712136.06,     1293740.63,
              217103.78,      557078.35,      513052.95,
              246547.79,      786449.21,      522747.90     },
       rev = {  415,            162,             99,
                 53,              8,              3,
                  1,              0,              0         },
       j2000 = 2451545.0, t, aa, ee, ii, nnode, llp, om, llam,
       ma, x, y, ea, eca, deca, p1, p2, p3, p, r},
t     = (jd - j2000)/36525;
aa    = a[[id]] + \[Delta]a[[id]]*t;
Print[\"Semimajor axis (AU) : \",aa];
ee    = e[[id]] + \[Delta]e[[id]]*t;
Print[\"Eccentricity        : \",ee];
ii    = Mod[i[[id]]    + \[Delta]i[[id]]*t/3600, 360];
Print[\"Inclination         : \",ii];
nnode = Mod[\[CapitalOmega][[id]] + \[Delta]\[CapitalOmega][[id]]*t/3600, 360];
If[nnode < 0, nnode = nnode + 360];
Print[\"Long. of Asc. Node  : \",nnode];
llp   = Mod[\[CurlyPi][[id]]   + \[Delta]\[CurlyPi][[id]]*t/3600, 360];
If[llp < 0, llp = llp + 360];
Print[\"Long. of Perihelion : \",llp];
\[Omega] = llp - nnode;
llam  = Mod[\[Lambda][[id]]  + 
            (\[Delta]\[Lambda][[id]]/3600 + rev[[id]]*360)*t, 360];
If[llam < 0, llam = llam + 360];
Print[\"Mean Longitude      : \",llam];
ma = Mod[llam - llp, 360];
If[ma < 0, ma = ma + 360];
Print[\"Mean Anomaly        : \",ma];
rma = N[ma \[Degree]];
eca = ea /. FindRoot[ea - ee Sin[ea] == rma, {ea,rma}];
deca = N[eca/\[Degree]];
If[deca < 0, deca = deca + 360];
Print[\"Eccentric Anomaly   : \",deca];
x = aa*(Cos[eca] - ee); 
y = aa*Sqrt[1-ee^2]*Sin[eca];
r = Sqrt[x^2 + y^2];
Print[\"Radius (AU)         : \",r];
Print[\"{x, y} coordinates  : \",{x,y}];
p1 = {{Cos[\[Omega] \[Degree]],    -Sin[\[Omega] \[Degree]],     0            \
 },
      {Sin[\[Omega] \[Degree]],     Cos[\[Omega] \[Degree]],     0            \
 },
      {0,                  0,                  1             }};
p2 = {{1,                  0,                  0             },
      {0,                  Cos[ii \[Degree]],    -Sin[ii \[Degree]]},
      {0,                  Sin[ii \[Degree]],     Cos[ii \[Degree]]}};
p3 = {{Cos[nnode \[Degree]], -Sin[nnode \[Degree]],  0             },
      {Sin[nnode \[Degree]],  Cos[nnode \[Degree]],  0             },
      {0,                  0,                  1             }};
p = N[p3.p2.p1];
Print[\"Rotation Matrix P1  : \",MatrixForm[N[p1]]];
Print[\"Rotation Matrix P2  : \",MatrixForm[N[p2]]];
Print[\"Rotation Matrix P3  : \",MatrixForm[N[p3]]];
Print[\"Rotation Matrix P   : \",MatrixForm[p]];
Print[\"{X, Y, Z} coords.   : \",p.{x, y, 0}]
]; \
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[6]:=",ExpressionUUID->"bb7e2e54-4215-44be-8d87-7ba594af6fa4"],

Cell[TextData[{
 "Here we define a function ",
 StyleBox["PlanetXYZ", "Input"],
 " that is identical to ",
 StyleBox["PrintPlanetXYZ", "Input"],
 " except that it does not print out any of the results.  Again it uses the \
data in Tables A.2 and A.3 to derive the ",
 StyleBox["(X,Y,Z)", "Input"],
 " coordinates of planet number ",
 StyleBox["id", "Input"],
 " at Julian Date ",
 StyleBox["jd", "Input"],
 ".  Note that ",
 StyleBox["id", "Input"],
 "=1,2,...,9 corresponds to Mercury, Venus, ..., Pluto."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"06eee10d-3ff4-41e5-a807-c90227427eee"],

Cell["\<\
PlanetXYZ[id_, jd_] :=
Module[{ a = {    0.38709893,     0.72333199,     1.00000011, 
                  1.52366231,     5.20336301,     9.53707032,
                 19.19126393,    30.06896348,    39.48168677},
        \[Delta]a = {    0.00000066,     0.00000092,    -0.00000005,
                 -0.00007221,     0.00060737,    -0.00301530,
                  0.00152025,    -0.00125196,    -0.00076912},
         e = {    0.20563069,     0.00677323,     0.01671022,
                  0.09341233,     0.04839266,     0.05415060,
                  0.04716771,     0.00858587,     0.24880766},
        \[Delta]e = {    0.00002527,    -0.00004938,    -0.00003804,
                  0.00011902,    -0.00012880,    -0.00036762,
                 -0.00019150,     0.00002514,     0.00006465},
         i = {    7.00487,        3.39471,        0.00005,
                  1.85061,        1.30530,        2.48446,
                  0.76986,        1.76917,       17.14175   },
        \[Delta]i = {  -23.51,          -2.86,         -46.94,
                -25.47,          -4.15,           6.11,
                 -2.09,          -3.64,          11.07      },
         \[CapitalOmega] = {   48.33167,       76.68069,      -11.26064,
                 49.57854,      100.55615,      113.71504,
                 74.22988,      131.72169,      110.30347   },
        \[Delta]\[CapitalOmega] = { -446.30,        -996.89,      -18228.25,
              -1020.19,        1217.17,       -1591.05,
               1681.40,        -151.25,         -37.33      },
         \[CurlyPi] = {   77.45645,      131.53298,      102.94719,
                336.04084,       14.75385,       92.43194,
                170.96424,       44.97135,      224.06676   },
        \[Delta]\[CurlyPi] = {  573.57,        -108.80,        1198.28,
               1560.78,         839.93,       -1948.89,
               1312.56,        -844.43,        -132.25      },
         \[Lambda] = {  252.25084,      181.97973,      100.46435,
                355.45332,       34.40438,       49.94432,
                313.23218,      304.88003,      238.92881   },
        \[Delta]\[Lambda] = {261628.29,      712136.06,     1293740.63,
              217103.78,      557078.35,      513052.95,
              246547.79,      786449.21,      522747.90     },
       rev = {  415,            162,             99,
                 53,              8,              3,
                  1,              0,              0         },
       j2000 = 2451545.0, t, aa, ee, ii, nnode, llp, om, llam,
       ma, x, y, ea, eca, p1, p2, p3, p, xx, yy, zz},
t     = (jd - j2000)/36525;
aa    = a[[id]] + \[Delta]a[[id]]*t;
ee    = e[[id]] + \[Delta]e[[id]]*t;
ii    = Mod[i[[id]]    + \[Delta]i[[id]]*t/3600, 360];
nnode = Mod[\[CapitalOmega][[id]] + \[Delta]\[CapitalOmega][[id]]*t/3600, 360];
If[nnode < 0, nnode = nnode + 360];
llp   = Mod[\[CurlyPi][[id]]   + \[Delta]\[CurlyPi][[id]]*t/3600, 360];
If[llp < 0, llp = llp + 360];
\[Omega] = llp - nnode;
llam  = Mod[\[Lambda][[id]]  + 
            (\[Delta]\[Lambda][[id]]/3600 + rev[[id]]*360)*t, 360];
If[llam < 0, llam = llam + 360];
ma = Mod[llam - llp, 360];
If[ma < 0, ma = ma + 360];
rma = N[ma \[Degree]];
eca = ea /. FindRoot[ea - ee Sin[ea] == rma, {ea,rma}];
x=aa*(Cos[eca] - ee); 
y=aa*Sqrt[1-ee^2]*Sin[eca];
p1 = {{Cos[\[Omega] \[Degree]],    -Sin[\[Omega] \[Degree]],     0            \
 },
      {Sin[\[Omega] \[Degree]],     Cos[\[Omega] \[Degree]],     0            \
 },
      {0,                  0,                  1             }};
p2 = {{1,                  0,                  0             },
      {0,                  Cos[ii \[Degree]],    -Sin[ii \[Degree]]},
      {0,                  Sin[ii \[Degree]],     Cos[ii \[Degree]]}};
p3 = {{Cos[nnode \[Degree]], -Sin[nnode \[Degree]],  0             },
      {Sin[nnode \[Degree]],  Cos[nnode \[Degree]],  0             },
      {0,                  0,                  1             }};
p = N[p3.p2.p1];
p.{x, y, 0}
]; \
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[7]:=",ExpressionUUID->"45fb1c85-be19-4c9b-9418-ea61b23d2895"],

Cell[TextData[{
 "Now define a function ",
 StyleBox["PlanetElements", "Input"],
 " that uses the data in Tables A.2 and A.3 to return the semi-major axis, \
eccentricity, inclination, argument of perihelion and longitude of ascending \
node for planet number ",
 StyleBox["id", "Input"],
 " at Julian date ",
 StyleBox["jd", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"08e74ed8-0797-4847-9022-fce34af1facb"],

Cell["\<\
PlanetElements[id_, jd_] :=
Module[{ a = {    0.38709893,     0.72333199,     1.00000011, 
                  1.52366231,     5.20336301,     9.53707032,
                 19.19126393,    30.06896348,    39.48168677},
        \[Delta]a = {    0.00000066,     0.00000092,    -0.00000005,
                 -0.00007221,     0.00060737,    -0.00301530,
                  0.00152025,    -0.00125196,    -0.00076912},
         e = {    0.20563069,     0.00677323,     0.01671022,
                  0.09341233,     0.04839266,     0.05415060,
                  0.04716771,     0.00858587,     0.24880766},
        \[Delta]e = {    0.00002527,    -0.00004938,    -0.00003804,
                  0.00011902,    -0.00012880,    -0.00036762,
                 -0.00019150,     0.00002514,     0.00006465},
         i = {    7.00487,        3.39471,        0.00005,
                  1.85061,        1.30530,        2.48446,
                  0.76986,        1.76917,       17.14175   },
        \[Delta]i = {  -23.51,          -2.86,         -46.94,
                -25.47,          -4.15,           6.11,
                 -2.09,          -3.64,          11.07      },
         \[CapitalOmega] = {   48.33167,       76.68069,      -11.26064,
                 49.57854,      100.55615,      113.71504,
                 74.22988,      131.72169,      110.30347   },
        \[Delta]\[CapitalOmega] = { -446.30,        -996.89,      -18228.25,
              -1020.19,        1217.17,       -1591.05,
               1681.40,        -151.25,         -37.33      },
         \[CurlyPi] = {   77.45645,      131.53298,      102.94719,
                336.04084,       14.75385,       92.43194,
                170.96424,       44.97135,      224.06676   },
        \[Delta]\[CurlyPi] = {  573.57,        -108.80,        1198.28,
               1560.78,         839.93,       -1948.89,
               1312.56,        -844.43,        -132.25      },
         \[Lambda] = {  252.25084,      181.97973,      100.46435,
                355.45332,       34.40438,       49.94432,
                313.23218,      304.88003,      238.92881   },
        \[Delta]\[Lambda] = {261628.29,      712136.06,     1293740.63,
              217103.78,      557078.35,      513052.95,
              246547.79,      786449.21,      522747.90     },
       rev = {  415,            162,             99,
                 53,              8,              3,
                  1,              0,              0         },
       j2000 = 2451545.0, t, aa, ee, ii, nnode, llp, om, llam,
       ma, x, y, ea, eca, p1, p2, p3, p, xx, yy, zz},
t     = (jd - j2000)/36525;
aa    = a[[id]] + \[Delta]a[[id]]*t;
ee    = e[[id]] + \[Delta]e[[id]]*t;
ii    = Mod[i[[id]]    + \[Delta]i[[id]]*t/3600, 360];
nnode = Mod[\[CapitalOmega][[id]] + \[Delta]\[CapitalOmega][[id]]*t/3600, 360];
If[nnode < 0, nnode = nnode + 360];
llp   = Mod[\[CurlyPi][[id]]   + \[Delta]\[CurlyPi][[id]]*t/3600, 360];
If[llp < 0, llp = llp + 360];
\[Omega] = llp - nnode;
{aa,ee,ii,\[Omega],nnode}
]\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[8]:=",ExpressionUUID->"0b613bbd-61c9-4a50-9f95-49c3cc5604ce"],

Cell[TextData[{
 "Now define a function ",
 StyleBox["OrbitXYZ", "Input"],
 " that returns a list of ",
 StyleBox["npts", "Input"],
 " values of ",
 StyleBox["(X,Y,Z)", "Input"],
 " around the orbit of planet ",
 StyleBox["id", "Input"],
 " at Julian date ",
 StyleBox["jd", "Input"],
 ".  Note that this function makes use of ",
 StyleBox["PlanetElements", "Input"],
 " to return the orbital elements at ",
 StyleBox["jd", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d05c996d-7459-4ae3-8619-4ae813fccd6d"],

Cell["\<\
OrbitXYZ[id_, jd_, npts_] :=
Module[{elem, a, e, ii, \[Omega], \[CapitalOmega], p1, p2, p3, p, x, y, z,
        f, r, cf, sf},
elem = PlanetElements[id, jd];
a   = elem[[1]];
e   = elem[[2]];
ii  = elem[[3]];
\[Omega]   = elem[[4]];
\[CapitalOmega]   = elem[[5]];
p1 = {{Cos[\[Omega] \[Degree]],    -Sin[\[Omega] \[Degree]],     0            \
 },
      {Sin[\[Omega] \[Degree]],     Cos[\[Omega] \[Degree]],     0            \
 },
      {0,            0,            1             }};
p2 = {{1,            0,            0             },
      {0,            Cos[ii \[Degree]],    -Sin[ii \[Degree]]},
      {0,            Sin[ii \[Degree]],     Cos[ii \[Degree]]}};
p3 = {{Cos[\[CapitalOmega] \[Degree]],   -Sin[\[CapitalOmega] \[Degree]],    \
0             },
      {Sin[\[CapitalOmega] \[Degree]],    Cos[\[CapitalOmega] \[Degree]],    \
0             },
      {0,           0,           1             }};
p = N[p3.p2.p1];
f = Table[N[t], {t,0,2Pi,2Pi/npts}];
cf = Cos[f];
sf = Sin[f];
ae = a*(1-e*e);
r = Map[ae/(1+e*Cos[#])&, f];
x = r*cf;
y = r*sf;
z = Table[0,{npts+1}];
Map[(p.#)&, Transpose[{x,y,z}]]
]\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[9]:=",ExpressionUUID->"301c4541-3032-4898-87ce-60761db513b7"],

Cell[TextData[{
 "In order to make drawings of the planetary orbits we need to be able to \
take the ",
 StyleBox["(X,Y)", "Input"],
 " coordinates from the list obtained from ",
 StyleBox["OrbitXYZ", "Input"],
 " and make them into a ",
 StyleBox["Line", "Input"],
 " of joined up points.  Hence we define a function ",
 StyleBox["OrbitXY", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a5208f34-cbff-4da1-9fbb-0f6646570de2"],

Cell["\<\
OrbitXY[id_, jd_, npts_] :=
  Line[Transpose[Take[Transpose[OrbitXYZ[id, jd, npts]],2]]];\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[10]:=",ExpressionUUID->"61107607-2ae0-4206-a89d-e7df8d7f046f"],

Cell[TextData[{
 "Now we can define a function ",
 StyleBox["PlotPlanets", "Input"],
 " that will draw the selected planetary orbits at the given Julian date ",
 StyleBox["jd", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"35ce9c0f-2e58-40f7-9127-35236564ad5e"],

Cell["\<\
PlotPlanets[idl_List, jd_, npts_] :=
Module[{},
  sun = Point[{0,0}];
  orbits = Map[OrbitXY[#, jd, npts]&, idl];
  positions = 
   Map[{PointSize[0.01],
        Point[Take[PlanetXYZ[#, jd], 2]]}&, idl];
  Show[Graphics[{sun, orbits, positions}],
      PlotRange->All,AspectRatio->1]
]\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[11]:=",ExpressionUUID->"b8a44336-b529-4244-80b6-beb20ad411bc"],

Cell[TextData[{
 "Finally we define a function ",
 StyleBox["PlotNeptunePluto", "Input"],
 " that uses the previous functions to plot the orbits of Neptune and Pluto \
at the specified date."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0591ee4e-3327-4b75-bf04-035f1a306d57"],

Cell["\<\
PlotNeptunePluto[jd_, npts_] :=
Module[{outer = {8,9}},
  sun = Point[{0,0}];
  orbits = Map[OrbitXY[#, jd, npts]&, outer];
  positions = 
   Map[{PointSize[0.03],
        Point[Take[PlanetXYZ[#, jd], 2]]}&, outer];
  Show[Graphics[{sun, orbits, positions}],AspectRatio->1]
]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[12]:=",ExpressionUUID->"d2b9c6a2-914d-4ff5-9142-8419adb4e9bc"],

Cell["Now do the plot.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"883787f3-cdd6-4b46-824f-abc770631d33"],

Cell[CellGroupData[{

Cell["nepplu= PlotNeptunePluto[date, 200]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[13]:=",ExpressionUUID->"45e9509a-8cd4-4b71-bdd6-d1d73d881e97"],

Cell[BoxData[
 GraphicsBox[{PointBox[{0, 0}], {LineBox[CompressedData["
1:eJwtl3k81XkXx5W6SbnWFGO5jP1y3c3df9cZamyNSkK7oUTlYaJJJkaUpMIM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     "]], LineBox[CompressedData["
1:eJwtV3k01YkXf0lEUpbsRPYly3vPe89bvu96m8kgZFJpKhEpIbIURRhbicrW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     "]]}, {
    {PointSize[0.03], PointBox[{6.018673911707431, -29.600708148802106`}]}, 
    {PointSize[0.03], PointBox[{-20.267394500921334`, -20.11523901824606}]}}},
  
  AspectRatio->1]], "Output",
 CellChangeTimes->{3.812012607836125*^9, 3.812012662283051*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"ebffe831-0d70-4a71-a4db-8244831e7a47"]
}, Open  ]],

Cell["Print out the elements for Neptune at that date.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ccbae12a-a978-4398-96ed-9c086150890b"],

Cell[CellGroupData[{

Cell["PrintPlanetXYZ[8, date]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[14]:=",ExpressionUUID->"939a0b24-550c-4922-8c09-5a6481323b92"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Semimajor axis (AU) : \"\>", "\[InvisibleSpace]", 
   "30.0690928591974`"}],
  SequenceForm["Semimajor axis (AU) : ", 30.0690928591974],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662325758*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"9794fae4-8cbe-4687-80f2-3e98a37ad3c1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Eccentricity        : \"\>", "\[InvisibleSpace]", 
   "0.008583271999247091`"}],
  SequenceForm["Eccentricity        : ", 0.008583271999247091],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.8120126623267193`*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"58851895-0c9f-4630-adf7-104b51bca6ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Inclination         : \"\>", "\[InvisibleSpace]", 
   "1.769274489555606`"}],
  SequenceForm["Inclination         : ", 1.769274489555606],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662327283*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"6b8a7cc2-3399-4cdb-9cf6-fb86cbedd1f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Long. of Asc. Node  : \"\>", "\[InvisibleSpace]", 
   "131.72603177068282`"}],
  SequenceForm["Long. of Asc. Node  : ", 131.72603177068282`],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662327828*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"30f7c2bb-7fd8-4fe1-a18a-f5b4d512c8db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Long. of Perihelion : \"\>", "\[InvisibleSpace]", 
   "44.99559014160456`"}],
  SequenceForm["Long. of Perihelion : ", 44.99559014160456],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.8120126623283863`*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"7901cfde-67e3-4b13-87e4-e9fa844ad789"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mean Longitude      : \"\>", "\[InvisibleSpace]", 
   "282.3042804231351`"}],
  SequenceForm["Mean Longitude      : ", 282.3042804231351],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662328937*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"bf2d5634-1a6e-4737-b03c-c344a1beb1ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mean Anomaly        : \"\>", "\[InvisibleSpace]", 
   "237.30869028153052`"}],
  SequenceForm["Mean Anomaly        : ", 237.30869028153052`],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662329493*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"751a42b4-c113-4c04-9261-a1db81760552"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Eccentric Anomaly   : \"\>", "\[InvisibleSpace]", 
   "236.89672790280522`"}],
  SequenceForm["Eccentric Anomaly   : ", 236.89672790280522`],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662330044*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"0c306014-77ee-499a-8fa4-a40ae8ec2f4a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Radius (AU)         : \"\>", "\[InvisibleSpace]", 
   "30.210049318311707`"}],
  SequenceForm["Radius (AU)         : ", 30.210049318311707`],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662330592*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"e4c60797-5deb-43aa-a295-cf06860d8a40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{x, y} coordinates  : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.680320292884385`"}], ",", 
     RowBox[{"-", "25.187576198229454`"}]}], "}"}]}],
  SequenceForm[
  "{x, y} coordinates  : ", {-16.680320292884385`, -25.187576198229454`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662331163*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"a3c2b277-d024-42dc-b782-d511d5de02d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Rotation Matrix P1  : \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.05703359320652661`", "0.9983722598539847`", "0.`"},
       {
        RowBox[{"-", "0.9983722598539847`"}], "0.05703359320652661`", "0.`"},
       {"0.`", "0.`", "1.`"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Rotation Matrix P1  : ", 
   MatrixForm[{{0.05703359320652661, 0.9983722598539847, 
    0.}, {-0.9983722598539847, 0.05703359320652661, 0.}, {0., 0., 1.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662331931*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"cd88552d-8314-48ec-8ac2-b06f3346ecc9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Rotation Matrix P2  : \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1.`", "0.`", "0.`"},
       {"0.`", "0.9995232610229519`", 
        RowBox[{"-", "0.030874757878304765`"}]},
       {"0.`", "0.030874757878304765`", "0.9995232610229519`"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Rotation Matrix P2  : ", 
   MatrixForm[{{1., 0., 0.}, {0., 
    0.9995232610229519, -0.030874757878304765`}, {0., 0.030874757878304765`, 
    0.9995232610229519}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.8120126623329477`*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"b23450e1-f18e-4205-87e9-e7b6f6701ff8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Rotation Matrix P3  : \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.6655695136554043`"}], 
        RowBox[{"-", "0.7463358644018849`"}], "0.`"},
       {"0.7463358644018849`", 
        RowBox[{"-", "0.6655695136554043`"}], "0.`"},
       {"0.`", "0.`", "1.`"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Rotation Matrix P3  : ", 
   MatrixForm[{{-0.6655695136554043, -0.7463358644018849, 0.}, {
    0.7463358644018849, -0.6655695136554043, 0.}, {0., 0., 1.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662333745*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"acc14417-97c9-4f30-a195-4c3248357b68"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Rotation Matrix P   : \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.7068059744259532`", 
        RowBox[{"-", "0.7070320625494886`"}], "0.023042939109303495`"},
       {"0.7067355690814237`", "0.70717929958668`", "0.020549297585291663`"},
       {
        RowBox[{"-", "0.030824501795407747`"}], "0.0017608983811812366`", 
        "0.9995232610229519`"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Rotation Matrix P   : ", 
   MatrixForm[{{0.7068059744259532, -0.7070320625494886, 
    0.023042939109303495`}, {0.7067355690814237, 0.70717929958668, 
    0.020549297585291663`}, {-0.030824501795407747`, 0.0017608983811812366`, 
    0.9995232610229519}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662334569*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"a25563c7-1387-4d05-aa85-583f8d951a60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{X, Y, Z} coords.   : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"6.018673911707431`", ",", 
     RowBox[{"-", "29.600708148802106`"}], ",", "0.46980980066264977`"}], 
    "}"}]}],
  SequenceForm[
  "{X, Y, Z} coords.   : ", {6.018673911707431, -29.600708148802106`, 
   0.46980980066264977`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8120126078713703`*^9, 3.812012662335284*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"3ed66b96-ad21-41f4-9c6a-a019283daa64"]
}, Open  ]],

Cell["Print out the elements for Pluto at that date.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f8911544-104c-4d42-be9b-5519c2668ac5"],

Cell[CellGroupData[{

Cell["PrintPlanetXYZ[9, date]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[15]:=",ExpressionUUID->"e7cbdc9b-7240-4470-af87-fe9d4a3b83c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Semimajor axis (AU) : \"\>", "\[InvisibleSpace]", 
   "39.481766251875065`"}],
  SequenceForm["Semimajor axis (AU) : ", 39.481766251875065`],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662342029*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"f840eba8-a8a0-44de-9e43-104c75898125"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Eccentricity        : \"\>", "\[InvisibleSpace]", 
   "0.24880097898374404`"}],
  SequenceForm["Eccentricity        : ", 0.24880097898374404`],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662342719*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"8a7382eb-70c2-4626-93d3-d92c6a46f763"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Inclination         : \"\>", "\[InvisibleSpace]", 
   "17.1414322254449`"}],
  SequenceForm["Inclination         : ", 17.1414322254449],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662343278*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"7f96dc23-040a-44ed-9522-d2b62af61e49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Long. of Asc. Node  : \"\>", "\[InvisibleSpace]", 
   "110.3045415920634`"}],
  SequenceForm["Long. of Asc. Node  : ", 110.3045415920634],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.8120126623438263`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"b91f6b2b-9f34-4612-b6b6-970e473f7207"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Long. of Perihelion : \"\>", "\[InvisibleSpace]", 
   "224.07055635816727`"}],
  SequenceForm["Long. of Perihelion : ", 224.07055635816727`],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662344369*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"edeeea01-85be-4470-b152-de4f26cac52a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mean Longitude      : \"\>", "\[InvisibleSpace]", 
   "223.9228496249721`"}],
  SequenceForm["Mean Longitude      : ", 223.9228496249721],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662344891*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"0cb226af-ed55-48d6-b3da-7209f2bfcc00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mean Anomaly        : \"\>", "\[InvisibleSpace]", 
   "359.85229326680485`"}],
  SequenceForm["Mean Anomaly        : ", 359.85229326680485`],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.8120126623454037`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"289caf0b-d125-4414-87ad-fb3564b020a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Eccentric Anomaly   : \"\>", "\[InvisibleSpace]", 
   "359.80337216498367`"}],
  SequenceForm["Eccentric Anomaly   : ", 359.80337216498367`],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662345912*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"58c815fd-fcc9-4454-b7c8-9914d882a8db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Radius (AU)         : \"\>", "\[InvisibleSpace]", 
   "29.658722001020347`"}],
  SequenceForm["Radius (AU)         : ", 29.658722001020347`],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662346425*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c96ac7b4-189c-44e7-bcd0-7abbfc140bff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{x, y} coordinates  : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"29.658431662866082`", ",", 
     RowBox[{"-", "0.13123274328860535`"}]}], "}"}]}],
  SequenceForm[
  "{x, y} coordinates  : ", {29.658431662866082`, -0.13123274328860535`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.8120126623469563`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"35b0e197-d3d3-41b4-930c-59b0cda22221"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Rotation Matrix P1  : \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.4030025131982181`"}], 
        RowBox[{"-", "0.9151988714787186`"}], "0.`"},
       {"0.9151988714787186`", 
        RowBox[{"-", "0.4030025131982181`"}], "0.`"},
       {"0.`", "0.`", "1.`"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Rotation Matrix P1  : ", 
   MatrixForm[{{-0.4030025131982181, -0.9151988714787186, 0.}, {
    0.9151988714787186, -0.4030025131982181, 0.}, {0., 0., 1.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662347611*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"ae0303b5-03c6-43d3-b434-9ea03e1463b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Rotation Matrix P2  : \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1.`", "0.`", "0.`"},
       {"0.`", "0.9555801359045646`", 
        RowBox[{"-", "0.29473140970146694`"}]},
       {"0.`", "0.29473140970146694`", "0.9555801359045646`"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Rotation Matrix P2  : ", 
   MatrixForm[{{1., 0., 0.}, {0., 
    0.9555801359045646, -0.29473140970146694`}, {0., 0.29473140970146694`, 
    0.9555801359045646}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662348357*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"e5e9aead-8d17-44a9-8457-5998a2b95819"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Rotation Matrix P3  : \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.3470099929388222`"}], 
        RowBox[{"-", "0.9378614315561753`"}], "0.`"},
       {"0.9378614315561753`", 
        RowBox[{"-", "0.3470099929388222`"}], "0.`"},
       {"0.`", "0.`", "1.`"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Rotation Matrix P3  : ", 
   MatrixForm[{{-0.3470099929388222, -0.9378614315561753, 0.}, {
    0.9378614315561753, -0.3470099929388222, 0.}, {0., 0., 1.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662349105*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c90bda60-fb12-45b2-aeb6-a0a863eb5520"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Rotation Matrix P   : \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.6803569348257329`"}], "0.6787547132152181`", 
        "0.2764172218271874`"},
       {
        RowBox[{"-", "0.6814366673417196`"}], 
        RowBox[{"-", "0.7246957603437854`"}], "0.10227474439935515`"},
       {"0.2697378535481144`", 
        RowBox[{"-", "0.11877749882814487`"}], "0.9555801359045646`"}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Rotation Matrix P   : ", 
   MatrixForm[{{-0.6803569348257329, 0.6787547132152181, 
    0.2764172218271874}, {-0.6814366673417196, -0.7246957603437854, 
    0.10227474439935515`}, {0.2697378535481144, -0.11877749882814487`, 
    0.9555801359045646}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662349876*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"22c64635-239b-4370-856b-7d743629a4ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{X, Y, Z} coords.   : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.267394500921334`"}], ",", 
     RowBox[{"-", "20.11523901824606`"}], ",", "8.015589193357108`"}], "}"}]}],
  SequenceForm[
  "{X, Y, Z} coords.   : ", {-20.267394500921334`, -20.11523901824606, 
   8.015589193357108}],
  Editable->False]], "Print",
 CellChangeTimes->{3.812012607884653*^9, 3.812012662350554*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"0149b909-43bd-4aaa-9418-a01fcdd99f1d"]
}, Open  ]],

Cell["\<\
Use the value of Neptune's longitude of ascending node to create a graphics \
object for an approximate line of nodes.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"25bc2d64-0292-47b0-a9d2-74d3e8260d4a"],

Cell[CellGroupData[{

Cell["\<\
nodeneptune = 
Graphics[Line[
{31*{Cos[131.726\[Degree]], Sin[131.726\[Degree]]},
 31*{Cos[(131.726+180)\[Degree]], Sin[(131.726+180)\[Degree]]}}]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[16]:=",ExpressionUUID->"354443c2-1b53-440c-a90b-974c9cf6e8d3"],

Cell[BoxData[
 GraphicsBox[
  LineBox[{{-20.632642094104128`, 23.136423237324355`}, {
   20.632642094104124`, -23.136423237324355`}}]]], "Output",
 CellChangeTimes->{3.8120126079311857`*^9, 3.812012662389175*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"a7bd4220-aa58-4f49-9e61-d15de3cf1208"]
}, Open  ]],

Cell["\<\
Use the value of Pluto's longitude of ascending node to create a graphics \
object for an approximate line of nodes.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"04495706-6ce1-4d0b-973d-f94725782b3c"],

Cell[CellGroupData[{

Cell["\<\
nodepluto = 
Graphics[Line[
{43*{Cos[110.305\[Degree]], Sin[110.305\[Degree]]},
 43*{Cos[(110.305+180)\[Degree]], Sin[(110.305+180)\[Degree]]}}]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[17]:=",ExpressionUUID->"f8b05aea-7687-461c-9fc5-356e71c914ab"],

Cell[BoxData[
 GraphicsBox[
  LineBox[{{-14.921752349575423`, 40.32792217332726}, {
   14.921752349575437`, -40.32792217332725}}]]], "Output",
 CellChangeTimes->{3.812012607935668*^9, 3.812012662393958*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"7e96a747-c01c-4dd8-8367-bcd4e6b3d615"]
}, Open  ]],

Cell["\<\
Display the orbits, the positions and the lines of nodes (see Fig.9.33).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b7b504ae-5d32-4bd5-a654-e7335b990758"],

Cell[CellGroupData[{

Cell["Show[nepplu, nodeneptune, nodepluto]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[18]:=",ExpressionUUID->"acec0e26-23e3-4883-8a9d-5b6be68a5487"],

Cell[BoxData[
 GraphicsBox[{{PointBox[{0, 0}], {LineBox[CompressedData["
1:eJwtl3k81XkXx5W6SbnWFGO5jP1y3c3df9cZamyNSkK7oUTlYaJJJkaUpMIM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      "]], LineBox[CompressedData["
1:eJwtV3k01YkXf0lEUpbsRPYly3vPe89bvu96m8kgZFJpKhEpIbIURRhbicrW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      "]]}, {
     {PointSize[0.03], PointBox[{6.018673911707431, -29.600708148802106`}]}, 
     {PointSize[0.03], 
      PointBox[{-20.267394500921334`, -20.11523901824606}]}}}, 
   LineBox[{{-20.632642094104128`, 23.136423237324355`}, {
    20.632642094104124`, -23.136423237324355`}}], 
   LineBox[{{-14.921752349575423`, 40.32792217332726}, {
    14.921752349575437`, -40.32792217332725}}]},
  AspectRatio->1]], "Output",
 CellChangeTimes->{3.8120126079750013`*^9, 3.8120126624355516`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"3da1bd4f-c0e9-4a20-a700-c6ce078ac6bd"]
}, Open  ]],

Cell["\<\
Calculate the Julian date at the start of 1989, our reference year.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"44624e13-118b-4f7a-8fd5-d2448cb843c0"],

Cell[CellGroupData[{

Cell["y1989 = JulianDate[{1989, 1, 1, 12.}]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[19]:=",ExpressionUUID->"4358373b-fb92-4021-82c4-b9223ccfc9ff"],

Cell[BoxData["2.4475279583333335`*^6"], "Output",
 CellChangeTimes->{3.812012607979443*^9, 3.812012662442111*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"1d5ac740-94e0-4427-ad77-dd07192b350e"]
}, Open  ]],

Cell[TextData[{
 "Define a simple function, ",
 StyleBox["Separation", "Input"],
 ", that calculates the distance between points defined by two position \
vectors, ",
 StyleBox["v1", "Input"],
 " and ",
 StyleBox["v2", "Input"],
 "."
}], "Text",ExpressionUUID->"22db8c4c-8895-4e6c-aa7e-c5e1a69173bd"],

Cell["\<\
Separation[v1_, v2_] :=
Sqrt[Apply[Plus, (v1-v2)^2]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[20]:=",ExpressionUUID->"87b46d49-809c-4588-bd50-9b7e38d7ae79"],

Cell["\<\
Calculate the separation of Neptune and Pluto for a period of 1000 years \
centred on 1989.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ec0f2008-1f7c-4344-8f46-1df20cefb24a"],

Cell["\<\
sep =
Table[{1989+i, 
       Separation[PlanetXYZ[8, y1989+i*365.25],
                  PlanetXYZ[9, y1989+i*365.25]]},
      {i,-500,500,2}];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[21]:=",ExpressionUUID->"642b2e99-3270-40bb-b88e-99654a888082"],

Cell["Plot the results (see Fig.9.34).", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8c574b9b-0d1f-49a6-908e-84d9128225c7"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[sep, PlotJoined->True, Frame->True, 
PlotRange->{{1489, 2489}, {0,80}}, AxesOrigin->{1489,0}]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[22]:=",ExpressionUUID->"598f8f82-a5b6-49bf-b271-65b3c227f122"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw12HlcTev3B/DSRCJDQjch6ZKo20iSjyRKhSQUIQmpkEoSkmRocimd+ey9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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1489., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{1489, 2489}, {0, 80}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8120126085515223`*^9, 3.812012662973608*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"76effd4a-7a57-464f-9174-3e25b6801b97"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{930, 530},
WindowMargins->{{246, Automatic}, {Automatic, 150}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"5e9b0490-ccc8-47a8-95ae-45b3cc69d324"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 119, 0, 67, "Section",ExpressionUUID->"6e8e70b0-1575-4ccc-baaf-e425552046ca"],
Cell[680, 22, 502, 15, 72, "Text",ExpressionUUID->"e296fbb8-279f-4311-9ffc-84626ebae8f5"],
Cell[1185, 39, 224, 6, 66, "Input",ExpressionUUID->"f765c5d6-1ee9-481a-8213-d99cb21b968a"],
Cell[1412, 47, 329, 8, 76, "Text",ExpressionUUID->"ac98eb6e-3dec-4709-8635-ac94d9793a73"],
Cell[CellGroupData[{
Cell[1766, 59, 781, 23, 372, "Input",ExpressionUUID->"da5b1b5f-250f-4787-875d-216292d581e1"],
Cell[2550, 84, 599, 12, 24, "Message",ExpressionUUID->"67f9b87f-7817-410f-886c-d4ef558c0d37"]
}, Open  ]],
Cell[3164, 99, 227, 6, 53, "Text",ExpressionUUID->"3c7aeaef-b3f9-4c07-be4d-8f4bc4dbd77f"],
Cell[CellGroupData[{
Cell[3416, 109, 162, 2, 30, "Input",ExpressionUUID->"8b1fa439-e43b-4175-b21b-50e24bbee1de"],
Cell[3581, 113, 191, 2, 34, "Output",ExpressionUUID->"f0580252-9f10-4a66-a33f-9b3a6759a615"]
}, Open  ]],
Cell[3787, 118, 543, 15, 99, "Text",ExpressionUUID->"1e6ea287-f3f6-406f-a963-81a6d3dcd9d1"],
Cell[4333, 135, 4823, 94, 1614, "Input",ExpressionUUID->"bb7e2e54-4215-44be-8d87-7ba594af6fa4"],
Cell[9159, 231, 628, 18, 99, "Text",ExpressionUUID->"06eee10d-3ff4-41e5-a807-c90227427eee"],
Cell[9790, 251, 4107, 77, 1308, "Input",ExpressionUUID->"45fb1c85-be19-4c9b-9418-ea61b23d2895"],
Cell[13900, 330, 462, 13, 76, "Text",ExpressionUUID->"08e74ed8-0797-4847-9022-fce34af1facb"],
Cell[14365, 345, 3147, 56, 966, "Input",ExpressionUUID->"0b613bbd-61c9-4a50-9f95-49c3cc5604ce"],
Cell[17515, 403, 560, 19, 76, "Text",ExpressionUUID->"d05c996d-7459-4ae3-8619-4ae813fccd6d"],
Cell[18078, 424, 1239, 36, 534, "Input",ExpressionUUID->"301c4541-3032-4898-87ce-60761db513b7"],
Cell[19320, 462, 478, 14, 76, "Text",ExpressionUUID->"a5208f34-cbff-4da1-9fbb-0f6646570de2"],
Cell[19801, 478, 218, 5, 48, "Input",ExpressionUUID->"61107607-2ae0-4206-a89d-e7df8d7f046f"],
Cell[20022, 485, 313, 9, 53, "Text",ExpressionUUID->"35ce9c0f-2e58-40f7-9127-35236564ad5e"],
Cell[20338, 496, 414, 13, 192, "Input",ExpressionUUID->"b8a44336-b529-4244-80b6-beb20ad411bc"],
Cell[20755, 511, 313, 8, 76, "Text",ExpressionUUID->"0591ee4e-3327-4b75-bf04-035f1a306d57"],
Cell[21071, 521, 411, 12, 174, "Input",ExpressionUUID->"d2b9c6a2-914d-4ff5-9142-8419adb4e9bc"],
Cell[21485, 535, 142, 3, 53, "Text",ExpressionUUID->"883787f3-cdd6-4b46-824f-abc770631d33"],
Cell[CellGroupData[{
Cell[21652, 542, 163, 2, 30, "Input",ExpressionUUID->"45e9509a-8cd4-4b71-bdd6-d1d73d881e97"],
Cell[21818, 546, 8923, 149, 377, "Output",ExpressionUUID->"ebffe831-0d70-4a71-a4db-8244831e7a47"]
}, Open  ]],
Cell[30756, 698, 174, 3, 53, "Text",ExpressionUUID->"ccbae12a-a978-4398-96ed-9c086150890b"],
Cell[CellGroupData[{
Cell[30955, 705, 151, 2, 30, "Input",ExpressionUUID->"939a0b24-550c-4922-8c09-5a6481323b92"],
Cell[31109, 709, 386, 9, 24, "Print",ExpressionUUID->"9794fae4-8cbe-4687-80f2-3e98a37ad3c1"],
Cell[31498, 720, 396, 9, 24, "Print",ExpressionUUID->"58851895-0c9f-4630-adf7-104b51bca6ed"],
Cell[31897, 731, 388, 9, 24, "Print",ExpressionUUID->"6b8a7cc2-3399-4cdb-9cf6-fb86cbedd1f7"],
Cell[32288, 742, 391, 9, 24, "Print",ExpressionUUID->"30f7c2bb-7fd8-4fe1-a18a-f5b4d512c8db"],
Cell[32682, 753, 390, 9, 24, "Print",ExpressionUUID->"7901cfde-67e3-4b13-87e4-e9fa844ad789"],
Cell[33075, 764, 388, 9, 24, "Print",ExpressionUUID->"bf2d5634-1a6e-4737-b03c-c344a1beb1ff"],
Cell[33466, 775, 391, 9, 24, "Print",ExpressionUUID->"751a42b4-c113-4c04-9261-a1db81760552"],
Cell[33860, 786, 391, 9, 24, "Print",ExpressionUUID->"0c306014-77ee-499a-8fa4-a40ae8ec2f4a"],
Cell[34254, 797, 391, 9, 24, "Print",ExpressionUUID->"e4c60797-5deb-43aa-a295-cf06860d8a40"],
Cell[34648, 808, 524, 13, 24, "Print",ExpressionUUID->"a3c2b277-d024-42dc-b782-d511d5de02d0"],
Cell[35175, 823, 1106, 27, 56, "Print",ExpressionUUID->"cd88552d-8314-48ec-8ac2-b06f3346ecc9"],
Cell[36284, 852, 1119, 28, 56, "Print",ExpressionUUID->"b23450e1-f18e-4205-87e9-e7b6f6701ff8"],
Cell[37406, 882, 1152, 29, 56, "Print",ExpressionUUID->"acc14417-97c9-4f30-a195-4c3248357b68"],
Cell[38561, 913, 1324, 31, 56, "Print",ExpressionUUID->"a25563c7-1387-4d05-aa85-583f8d951a60"],
Cell[39888, 946, 559, 14, 24, "Print",ExpressionUUID->"3ed66b96-ad21-41f4-9c6a-a019283daa64"]
}, Open  ]],
Cell[40462, 963, 172, 3, 53, "Text",ExpressionUUID->"f8911544-104c-4d42-be9b-5519c2668ac5"],
Cell[CellGroupData[{
Cell[40659, 970, 151, 2, 30, "Input",ExpressionUUID->"e7cbdc9b-7240-4470-af87-fe9d4a3b83c2"],
Cell[40813, 974, 389, 9, 24, "Print",ExpressionUUID->"f840eba8-a8a0-44de-9e43-104c75898125"],
Cell[41205, 985, 391, 9, 24, "Print",ExpressionUUID->"8a7382eb-70c2-4626-93d3-d92c6a46f763"],
Cell[41599, 996, 384, 9, 24, "Print",ExpressionUUID->"7f96dc23-040a-44ed-9522-d2b62af61e49"],
Cell[41986, 1007, 388, 9, 24, "Print",ExpressionUUID->"b91f6b2b-9f34-4612-b6b6-970e473f7207"],
Cell[42377, 1018, 389, 9, 24, "Print",ExpressionUUID->"edeeea01-85be-4470-b152-de4f26cac52a"],
Cell[42769, 1029, 386, 9, 24, "Print",ExpressionUUID->"0cb226af-ed55-48d6-b3da-7209f2bfcc00"],
Cell[43158, 1040, 391, 9, 24, "Print",ExpressionUUID->"289caf0b-d125-4414-87ad-fb3564b020a0"],
Cell[43552, 1051, 389, 9, 24, "Print",ExpressionUUID->"58c815fd-fcc9-4454-b7c8-9914d882a8db"],
Cell[43944, 1062, 389, 9, 24, "Print",ExpressionUUID->"c96ac7b4-189c-44e7-bcd0-7abbfc140bff"],
Cell[44336, 1073, 504, 12, 24, "Print",ExpressionUUID->"35b0e197-d3d3-41b4-930c-59b0cda22221"],
Cell[44843, 1087, 1150, 29, 56, "Print",ExpressionUUID->"ae0303b5-03c6-43d3-b434-9ea03e1463b6"],
Cell[45996, 1118, 1111, 28, 56, "Print",ExpressionUUID->"e5e9aead-8d17-44a9-8457-5998a2b95819"],
Cell[47110, 1148, 1150, 29, 56, "Print",ExpressionUUID->"c90bda60-fb12-45b2-aeb6-a0a863eb5520"],
Cell[48263, 1179, 1360, 33, 56, "Print",ExpressionUUID->"22c64635-239b-4370-856b-7d743629a4ed"],
Cell[49626, 1214, 569, 14, 24, "Print",ExpressionUUID->"0149b909-43bd-4aaa-9418-a01fcdd99f1d"]
}, Open  ]],
Cell[50210, 1231, 252, 6, 53, "Text",ExpressionUUID->"25bc2d64-0292-47b0-a9d2-74d3e8260d4a"],
Cell[CellGroupData[{
Cell[50487, 1241, 283, 7, 84, "Input",ExpressionUUID->"354443c2-1b53-440c-a90b-974c9cf6e8d3"],
Cell[50773, 1250, 291, 5, 418, "Output",ExpressionUUID->"a7bd4220-aa58-4f49-9e61-d15de3cf1208"]
}, Open  ]],
Cell[51079, 1258, 250, 6, 53, "Text",ExpressionUUID->"04495706-6ce1-4d0b-973d-f94725782b3c"],
Cell[CellGroupData[{
Cell[51354, 1268, 281, 7, 84, "Input",ExpressionUUID->"f8b05aea-7687-461c-9fc5-356e71c914ab"],
Cell[51638, 1277, 285, 5, 449, "Output",ExpressionUUID->"7e96a747-c01c-4dd8-8367-bcd4e6b3d615"]
}, Open  ]],
Cell[51938, 1285, 206, 5, 53, "Text",ExpressionUUID->"b7b504ae-5d32-4bd5-a654-e7335b990758"],
Cell[CellGroupData[{
Cell[52169, 1294, 164, 2, 30, "Input",ExpressionUUID->"acec0e26-23e3-4883-8a9d-5b6be68a5487"],
Cell[52336, 1298, 9153, 153, 377, "Output",ExpressionUUID->"3da1bd4f-c0e9-4a20-a700-c6ce078ac6bd"]
}, Open  ]],
Cell[61504, 1454, 201, 5, 53, "Text",ExpressionUUID->"44624e13-118b-4f7a-8fd5-d2448cb843c0"],
Cell[CellGroupData[{
Cell[61730, 1463, 165, 2, 30, "Input",ExpressionUUID->"4358373b-fb92-4021-82c4-b9223ccfc9ff"],
Cell[61898, 1467, 192, 2, 34, "Output",ExpressionUUID->"1d5ac740-94e0-4427-ad77-dd07192b350e"]
}, Open  ]],
Cell[62105, 1472, 300, 9, 35, "Text",ExpressionUUID->"22db8c4c-8895-4e6c-aa7e-c5e1a69173bd"],
Cell[62408, 1483, 188, 5, 48, "Input",ExpressionUUID->"87b46d49-809c-4588-bd50-9b7e38d7ae79"],
Cell[62599, 1490, 225, 6, 53, "Text",ExpressionUUID->"ec0f2008-1f7c-4344-8f46-1df20cefb24a"],
Cell[62827, 1498, 278, 8, 102, "Input",ExpressionUUID->"642b2e99-3270-40bb-b88e-99654a888082"],
Cell[63108, 1508, 158, 3, 53, "Text",ExpressionUUID->"8c574b9b-0d1f-49a6-908e-84d9128225c7"],
Cell[CellGroupData[{
Cell[63291, 1515, 238, 5, 48, "Input",ExpressionUUID->"598f8f82-a5b6-49bf-b271-65b3c227f122"],
Cell[63532, 1522, 8067, 146, 276, "Output",ExpressionUUID->"76effd4a-7a57-464f-9174-3e25b6801b97"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

